@@ -139,7 +139,7 @@ title
     def generate_integer(self, entity, attrname, index):
         """generates a consistent value for 'attrname' if it's an integer"""
         return self._constrained_generate(entity, attrname, 0, 1, index)
-    generate_int = generate_integer
+    generate_int = generate_bigint = generate_integer
 
     def generate_float(self, entity, attrname, index):
         """generates a consistent value for 'attrname' if it's a float"""
@@ -384,10 +384,10 @@ def make_relations_queries(schema, edict, cursor, ignored_relations=(),
 
 def composite_relation(rschema):
     for obj in rschema.objects():
-        if obj.rdef(rschema, 'object').composite == 'subject':
+        if obj.rdef(rschema, 'object', takefirst=True).composite == 'subject':
             return True
     for obj in rschema.subjects():
-        if obj.rdef(rschema, 'subject').composite == 'object':
+        if obj.rdef(rschema, 'subject', takefirst=True).composite == 'object':
             return True
     return False
 
