@@ -1,4 +1,4 @@
-# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of CubicWeb.
@@ -20,14 +20,10 @@ from logilab.database import FunctionDescr
 from logilab.database.sqlite import register_sqlite_pyfunc
 from rql.utils import register_function
 
-try:
-    class DUMB_SORT(FunctionDescr):
-        pass
-
-    register_function(DUMB_SORT)
-    def dumb_sort(something):
-        return something
-    register_sqlite_pyfunc(dumb_sort)
-except:
-    # already registered
+class DUMB_SORT(FunctionDescr):
     pass
+
+register_function(DUMB_SORT)
+def dumb_sort(something):
+    return something
+register_sqlite_pyfunc(dumb_sort)
