@@ -1,4 +1,4 @@
-# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of CubicWeb.
@@ -37,7 +37,7 @@ def pformat(obj):
     """pretty prints `obj` if possible"""
     try:
         return _pformat(obj)
-    except:
+    except Exception:
         return u'<could not parse>'
 
 def qs2dict(qs):
